require 'mochee/movie'
require_relative 'spec_helper'

module Mochee
	RSpec.describe Movie do
		before do
			$stdout = StringIO.new
		end

		context "Let's unit test Movie methods" do
		    before do
			   @initial_rank = 10
			   @movie = Movie.new('goonies',@initial_rank)
		    end

			it "has a capitalized title" do
				@movie.title.should_not == "goonies"
				@movie.title.should == "Goonies"
			end

			it "has an initial rank" do
				@movie.rank.should == 10
			end

			it "has a string representation" do
				@movie.to_s.should == "Goonies with a rank of 10 (Hit)"
			end

			it "increases rank by 1 when given a thumbs up" do
				@movie.thumbs_up
				@movie.rank.should == @initial_rank + 1
			end

			it "decreases rank by 1 when given a thumbs down" do
				@movie.thumbs_down
				@movie.rank.should == @initial_rank - 1
			end
		end

		context "can have default values" do
			before do
				@movie = Movie.new('goonies')
			end
			
			it "has a default rank of 0 if not initialized" do
				@movie.rank.should == 0 
			end
		end

		context "with a rank of at least 10." do
			before do
				@movie = Movie.new('lawyer',10)
			end

			it "is a Hit" do 
				expect(@movie).to be_hit
			end

			it "has a HIT status" do
				expect(@movie.status).to eq("Hit")
			end


		end

		context 'with a rank less than 10.' do
			before do
				@movie = Movie.new('fantastic 4',5)
			end

			it "is not a hit" do
				expect(@movie).to_not be_hit
			end

			it 'has a Flop status' do
				expect(@movie.status).to eq('Flop')
			end
		end
	end
end
